@@ -1,4 +1,4 @@
-# Copyright (C) 2012-2014 The python-bitcoinlib developers
+# Copyright (C) 2012-2018 The python-bitcoinlib developers
 #
 # This file is part of python-bitcoinlib.
 #
@@ -9,14 +9,13 @@
 # propagated, or distributed except according to the terms contained in the
 # LICENSE file.
 
-from __future__ import absolute_import, division, print_function, unicode_literals
 
 import bitcoin.core
 
 # Note that setup.py can break if __init__.py imports any external
 # dependencies, as these might not be installed when setup.py runs. In this
 # case __version__ could be moved to a separate version.py and imported here.
-__version__ = '0.6.0'
+__version__ = '0.11.1'
 
 class MainParams(bitcoin.core.CoreMainParams):
     MESSAGE_START = b'\xf9\xbe\xb4\xd9'
@@ -26,29 +25,46 @@ class MainParams(bitcoin.core.CoreMainParams):
                  ('bluematt.me', 'dnsseed.bluematt.me'),
                  ('dashjr.org', 'dnsseed.bitcoin.dashjr.org'),
                  ('bitcoinstats.com', 'seed.bitcoinstats.com'),
-                 ('xf2.org', 'bitseed.xf2.org'))
+                 ('xf2.org', 'bitseed.xf2.org'),
+                 ('bitcoin.jonasschnelli.ch', 'seed.bitcoin.jonasschnelli.ch'))
     BASE58_PREFIXES = {'PUBKEY_ADDR':0,
                        'SCRIPT_ADDR':5,
                        'SECRET_KEY' :128}
+    BECH32_HRP = 'bc'
 
 class TestNetParams(bitcoin.core.CoreTestNetParams):
     MESSAGE_START = b'\x0b\x11\x09\x07'
     DEFAULT_PORT = 18333
     RPC_PORT = 18332
-    DNS_SEEDS = (('bitcoin.petertodd.org', 'testnet-seed.bitcoin.petertodd.org'),
-                 ('bluematt.me', 'testnet-seed.bluematt.me'))
+    DNS_SEEDS = (('testnetbitcoin.jonasschnelli.ch', 'testnet-seed.bitcoin.jonasschnelli.ch'),
+                 ('petertodd.org', 'seed.tbtc.petertodd.org'),
+                 ('bluematt.me', 'testnet-seed.bluematt.me'),
+                 ('bitcoin.schildbach.de', 'testnet-seed.bitcoin.schildbach.de'))
+    BASE58_PREFIXES = {'PUBKEY_ADDR':111,
+                       'SCRIPT_ADDR':196,
+                       'SECRET_KEY' :239}
+    BECH32_HRP = 'tb'
+
+class SigNetParams(bitcoin.core.CoreSigNetParams):
+    MESSAGE_START = b'\x0a\x03\xcf\x40'
+    DEFAULT_PORT = 38333
+    RPC_PORT = 38332
+    DNS_SEEDS = (("signet.bitcoin.sprovoost.nl", "seed.signet.bitcoin.sprovoost.nl"))
     BASE58_PREFIXES = {'PUBKEY_ADDR':111,
                        'SCRIPT_ADDR':196,
                        'SECRET_KEY' :239}
 
+    BECH32_HRP = 'tb'
+
 class RegTestParams(bitcoin.core.CoreRegTestParams):
     MESSAGE_START = b'\xfa\xbf\xb5\xda'
     DEFAULT_PORT = 18444
-    RPC_PORT = 18332
+    RPC_PORT = 18443
     DNS_SEEDS = ()
     BASE58_PREFIXES = {'PUBKEY_ADDR':111,
                        'SCRIPT_ADDR':196,
                        'SECRET_KEY' :239}
+    BECH32_HRP = 'bcrt'
 
 """Master global setting for what chain params we're using.
 
@@ -73,5 +89,7 @@ def SelectParams(name):
         params = bitcoin.core.coreparams = TestNetParams()
     elif name == 'regtest':
         params = bitcoin.core.coreparams = RegTestParams()
+    elif name == 'signet':
+        params = bitcoin.core.coreparams = SigNetParams()
     else:
         raise ValueError('Unknown chain %r' % name)
